(import (chicken format) (chicken pathname) (chicken process-context) (chicken string) pkg-config srfi-1 test)

(set-environment-variable! "PKG_CONFIG_LIBDIR" (current-directory))

(test "pkg-config libs happy path"
      '("-L/usr/local/lib" "-lcurl")
      (pkg-config:libs "libcurl"))

(define (clean-list l) (filter (lambda (x) (substring=? x "-l" 0 0 2)) l))

;; The output of pkg-config --libs --static differs slightly between
;; pkg-config implementations.  Under the standard pkg-config, it can
;; contain -L/usr/lib that is inserted implicitly.  On the other hand,
;; pkgconf (another pkg-config implementation) doesn't appear to insert
;; implicit -L/usr/lib.
;; For testing purposes, we'll sanitize the two lists so that they only
;; contain -llibrary arguments and no other linker flags'
(test "pkg-config static libs happy path"
      (clean-list
       (map
	symbol->string
	'(
	  -L/usr/local/lib
	  -lcurl -lnghttp2 -lssl -lcrypto
	  -L/usr/lib -lgssapi -lgssapi_krb5 -lheimntlm -lkrb5 -lhx509
	  -lcom_err -lcrypto -lasn1 -lwind -lheimbase -lroken -lcrypt
	  -pthread -lz -lkrb5 -lgssapi -lgssapi_krb5 -lkrb5 -lgssapi
	  -lgssapi_krb5 -L/usr/local/lib -pthread)))
      (clean-list (pkg-config:libs "libcurl" static: #t)))

(test "pkg-config cflags happy path"
      '("-I/usr/local/include")
      (pkg-config:cflags "libcurl"))

(test "pkg-config libs happy path (empty)"
      '()
      (pkg-config:libs "zlib"))
(test "pkg-config static libs happy path (empty)"
      '()
      (pkg-config:libs "zlib" static: #t))

(test "pkg-config cflags happy path (empty)"
      '()
      (pkg-config:cflags "zlib"))

(test "#f returned as cflags for nonexistent package"
      #f
      (pkg-config:cflags "not-a-real-package"))

(test "#f returned as libs for nonexistent package"
      #f
      (pkg-config:libs "not-a-real-package"))

(test "#f returned as static libs for nonexistent package"
      #f
      (pkg-config:libs "not-a-real-package" static: #t))

(unless (zero? (test-failure-count))
  (print "=====")
  (printf "===== ~a ~a failed!\n"
          (test-failure-count)
          (if (> (test-failure-count) 1) "tests" "test"))
  (print "====="))
(test-exit)
